@@ -1,3 +1,5 @@
+from typing import Optional
+
 from telethon.errors import MessageIdInvalidError
 from telethon.tl.custom import Message
 
@@ -17,7 +19,9 @@ def get_variable_names(include_orig=True):
     # fmt: on
 
 
-async def eval_message(code: str, message: Message, uses_orig=False) -> None:
+async def eval_message(
+    code: str, message: Message, uses_orig: bool
+) -> Optional[Message]:
     await message_design.edit_message(message, code, 'Running...')
 
     app.ctx.msg = message
@@ -50,8 +54,12 @@ async def eval_message(code: str, message: Message, uses_orig=False) -> None:
 
     try:
         # noinspection PyProtectedMember
-        await message_design.edit_message(
-            message, code, result, traceback=exc, output=app.ctx._print_output
+        return await message_design.edit_message(
+            message,
+            code,
+            result,
+            traceback=exc,
+            output=app.ctx._print_output,
         )
     except MessageIdInvalidError:
-        pass
+        return None
