@@ -1,6 +1,7 @@
 import ast
 
 from tgpy import app
+from tgpy.run_code.utils import apply_code_transformers
 
 
 class _Result:
@@ -23,10 +24,10 @@ def _is_node_suspicious_binop(node: ast.AST, locs: dict) -> bool:
     if not isinstance(node, (ast.BoolOp, ast.BinOp, ast.Compare)):
         return False
     if isinstance(node, ast.Compare):
-        return _is_node_unknown_variable(node.left, locs) and all(
+        return _is_node_unknown_variable(node.left, locs) or any(
             _is_node_unknown_variable(x, locs) for x in node.comparators
         )
-    return all(
+    return any(
         _is_node_suspicious_binop(operand, locs)
         for operand in (
             (node.left, node.right) if isinstance(node, ast.BinOp) else node.values
@@ -45,6 +46,8 @@ def _ignore_node_simple(node: ast.AST, locs: dict) -> bool:
 
 def _ignore_node(node: ast.AST, locs: dict) -> bool:
     """Check if AST node didn't seem to be meant to be code"""
+    if isinstance(node, ast.Expr):
+        return _ignore_node(node.value, locs)
     return (
         _ignore_node_simple(node, locs)
         # Messages like "-1", "+spam" and "not foo.bar"
@@ -59,16 +62,16 @@ def _ignore_node(node: ast.AST, locs: dict) -> bool:
         or _is_node_suspicious_binop(node, locs)
         # Messages like "yes, understood"
         or isinstance(node, ast.Tuple)
-        and all(_ignore_node_simple(elt, locs) for elt in node.elts)
+        and any(_ignore_node(elt, locs) for elt in node.elts)
         # Messages like "cat (no)"
         or isinstance(node, ast.Call)
-        and _ignore_node_simple(node.func, locs)
-        and all(_ignore_node_simple(arg, locs) for arg in node.args)
+        and _ignore_node(node.func, locs)
+        and any(_ignore_node(arg, locs) for arg in node.args)
         # Messages like "fix: fix"
         or isinstance(node, ast.AnnAssign)
         and node.value is None
-        and _ignore_node_simple(node.target, locs)
-        and _ignore_node_simple(node.annotation, locs)
+        and _ignore_node(node.target, locs)
+        and _ignore_node(node.annotation, locs)
     )
 
 
@@ -76,18 +79,14 @@ def parse_code(text: str, locs: dict) -> _Result:
     """Parse given text and decide should it be evaluated as Python code"""
     result = _Result()
 
-    # noinspection PyProtectedMember
-    text = app.api._apply_code_transformers(text)
+    text = apply_code_transformers(app, text)
 
     try:
         root = ast.parse(text, '', 'exec')
     except (SyntaxError, ValueError):
         return result
 
-    if all(
-        isinstance(body_item, ast.Expr) and _ignore_node(body_item.value, locs)
-        for body_item in root.body
-    ):
+    if all(_ignore_node(body_item, locs) for body_item in root.body):
         return result
 
     result.is_code = True
